################
contrib packages
################

Odin provides integration with other Python libraries to simplify common development situations. These packages are kept
separate from the rest of Odin to only require dependencies on other libraries if you so chose to use this additional
functionality.

This code lives in ``odin/contrib`` in the Odin distribution.

.. toctree::
   :maxdepth: 1

   doc_gen/index
   geo/index
   money/index
   pint/index
   sphinx/index
